##  Best Practices
Automate the creation and management of AI agent fact sheets using AI agent discovery. This enables you to:
  * Keep up with frequent changes due to the short-lived nature of agents.
  * Avoid the difficulties of manual maintenance as the number of agents increases.


To learn how to use AI agent discovery and the features of the AI agent hub, see [AI Agent Hub](https://help.sap.com/docs/leanix/ea/ai-agent-hub?locale=en-US&state=PRODUCTION&version=CLOUD "Discover and manage AI agents across the organization.").
